@@ -926,7 +926,7 @@ int main (int argc, char *argv[])
     }
 
   // Handle here the general file (not required to be image)
-  if ( explicitts || implicit || deflated )
+  if ( !raw && (explicitts || implicit || deflated) )
     {
     if( explicitts && implicit ) return 1; // guard
     if( explicitts && deflated ) return 1; // guard
@@ -1261,11 +1261,15 @@ int main (int argc, char *argv[])
       if( ts.IsExplicit() )
         {
         change.SetTransferSyntax( gdcm::TransferSyntax::ExplicitVRLittleEndian );
+        if( implicit )
+          change.SetTransferSyntax( gdcm::TransferSyntax::ImplicitVRLittleEndian );
         }
       else
         {
         assert( ts.IsImplicit() );
         change.SetTransferSyntax( gdcm::TransferSyntax::ImplicitVRLittleEndian );
+        if( explicitts )
+        change.SetTransferSyntax( gdcm::TransferSyntax::ExplicitVRLittleEndian );
         }
 #endif
       }
