@@ -70,14 +70,6 @@
 #include <getopt.h>
 #include <string.h>
 
-#ifndef GDCM_HAVE_ATOLL
-#ifdef _MSC_VER
-#define atoll _atoi64
-#else
-#define atoll atol
-#endif
-#endif
-
 static unsigned int readsize(const char *str, unsigned int * size)
 {
   int n = sscanf( str, "%i,%i,%i", size, size+1, size+2);
@@ -460,15 +452,15 @@ int main (int argc, char *argv[])
   // Too early for UID Generation
   std::string series_uid; // = uid.Generate();
   std::string study_uid; // = uid.Generate();
-  while (1) {
+  while (true) {
     //int this_option_optind = optind ? optind : 1;
     int option_index = 0;
     static struct option long_options[] = {
-        {"input", 1, 0, 0},
-        {"output", 1, 0, 0},
+        {"input", 1, nullptr, 0},
+        {"output", 1, nullptr, 0},
         // provide convert-like command line args:
         {"depth", 1, &depth, 1},
-        {"size", 1, 0, 0},
+        {"size", 1, nullptr, 0},
         {"region", 1, &bregion, 1},
         {"fill", 1, &fill, 1},
         {"study-uid", 1, &studyuid, 1},
@@ -492,7 +484,7 @@ int main (int argc, char *argv[])
         {"error", 0, &error, 1},
         {"help", 0, &help, 1},
         {"version", 0, &version, 1},
-        {0, 0, 0, 0}
+        {nullptr, 0, nullptr, 0}
     };
 
     // i -> input file
@@ -596,7 +588,7 @@ int main (int argc, char *argv[])
             {
             assert( strcmp(s, "offset") == 0 );
             poffset = 1;
-            start_pos = (size_t)atoll(optarg);
+            start_pos = (size_t)std::atoll(optarg);
             }
           else if( option_index == 17 ) /* template */
             {
@@ -696,7 +688,7 @@ int main (int argc, char *argv[])
     while (optind < argc)
       {
       //printf ("%s\n", argv[optind++]);
-      files.push_back( argv[optind++] );
+      files.emplace_back(argv[optind++] );
       }
     //printf ("\n");
     if( files.size() >= 2
@@ -918,6 +910,16 @@ int main (int argc, char *argv[])
         }
 
       if( !Populate( writer, raw, filenames, ndimension, start_pos ) ) return 1;
+      // populate will guess pixel format and photometric inter from file, need
+      // to override after calling Populate:
+      if( pformat )
+        {
+        writer.GetPixmap().SetPixelFormat( pfref );
+        }
+      if( pinter )
+        {
+        writer.GetPixmap().SetPhotometricInterpretation( refpi );
+        }
       if( !AddUIDs(sopclassuid, sopclass, study_uid, series_uid, writer ) ) return 1;
 
       writer.SetFileName( outfilename );
@@ -1211,9 +1213,9 @@ int main (int argc, char *argv[])
     gdcm::ByteValue *bv = new gdcm::ByteValue();
     bv->SetLength( (uint32_t)len );
     //memcpy( bv->GetPointer(), imageori
-    imageori.GetBuffer( (char*)bv->GetPointer() );
+    imageori.GetBuffer( (char*)bv->GetVoidPointer() );
     // Rub out pixels:
-    char *p = (char*)bv->GetPointer();
+    char *p = (char*)bv->GetVoidPointer();
     switch(pixeltype)
       {
     case gdcm::PixelFormat::UINT8:
