@@ -106,7 +106,11 @@ static std::string getInfoDate(Dict *infoDict, const char *key)
   return out;
 }
 
+#ifdef LIBPOPPLER_UNICODEMAP_HAS_CONSTMAPUNICODE
+static std::string getInfoString(Dict *infoDict, const char *key, const UnicodeMap *uMap, bool & unicode)
+#else
 static std::string getInfoString(Dict *infoDict, const char *key, UnicodeMap *uMap, bool & unicode)
+#endif
 {
   Object obj;
 #ifdef LIBPOPPLER_GOOSTRING_HAS_CONSTGETCHAR
@@ -333,13 +337,21 @@ int main (int argc, char *argv[])
   GooString *fileName;
   PDFDoc *doc;
   Object info;
+#ifdef LIBPOPPLER_UNICODEMAP_HAS_CONSTMAPUNICODE
+  const UnicodeMap *uMap;
+#else
   UnicodeMap *uMap;
+#endif
   ownerPW = NULL;
   userPW = NULL;
 #ifdef LIBPOPPLER_GLOBALPARAMS_CSTOR_HAS_PARAM
   globalParams = new GlobalParams(0);
+#else
+#ifdef LIBPOPPLER_GLOBALPARAMS_HAS_RESET
+  globalParams.reset(new GlobalParams());
 #else
   globalParams = new GlobalParams();
+#endif
 #endif
   uMap = globalParams->getTextEncoding();
 
