@@ -20,7 +20,7 @@
 #include "gdcmImplicitDataElement.h"
 #include "gdcmTrace.h"
 
-namespace gdcm
+namespace gdcm_ns
 {
   void DataElement::SetVLToUndefined() {
     assert( VRField == VR::SQ || VRField == VR::INVALID
@@ -56,7 +56,7 @@ namespace gdcm
     {
     if( IsEmpty() /*|| GetByteValue()*/ || GetSequenceOfFragments() )
       {
-      return 0;
+      return nullptr;
       }
     SequenceOfItems *sq = dynamic_cast<SequenceOfItems*>(ValueField.GetPointer());
     if( sq ) // all set !
@@ -104,7 +104,7 @@ namespace gdcm
             else
               {
               delete sqi;
-              sqi = NULL;
+              sqi = nullptr;
               }
             }
           return sqi;
@@ -153,7 +153,7 @@ namespace gdcm
                 gdcmErrorMacro( "Could not read SQ. Giving up" );
                 gdcmErrorMacro(ex2.what()); (void)ex2;
                 delete sqi;
-                return NULL;
+                return nullptr;
                 }
               }
             }
@@ -163,7 +163,7 @@ namespace gdcm
           {
           assert( GetVR().IsVRFile() );
           assert( GetByteValue() );
-          return 0;
+          return nullptr;
           }
         }
       }
@@ -189,4 +189,4 @@ void DataElement::SetValueFieldLength( VL vl, bool readvalues )
     ValueField->SetLengthOnly(vl); // do not perform realloc
 }
 
-} // end namespace gdcm
+} // end namespace gdcm_ns
