@@ -72,7 +72,7 @@ void TableReader::HandleMacroEntryDescription(const char **atts)
   (void)atts;
   assert( ParsingMacroEntryDescription == false );
   ParsingMacroEntryDescription = true;
-  assert( *atts == NULL );
+  assert( *atts == nullptr );
   assert( Description == "" );
 }
 
@@ -91,7 +91,7 @@ void TableReader::HandleModuleEntryDescription(const char **atts)
   (void)atts;
   assert( ParsingModuleEntryDescription == false );
   ParsingModuleEntryDescription = true;
-  assert( *atts == NULL );
+  assert( *atts == nullptr );
   assert( Description == "" );
 }
 
