@@ -78,7 +78,7 @@ public:
     os << "TypeOfData                         :" << TypeOfData << std::endl;
     os << "CurveDescription                   :" << CurveDescription << std::endl;
     os << "DataValueRepresentation            :" << DataValueRepresentation << std::endl;
-    const unsigned short * p = (const unsigned short*)&Data[0];
+    const unsigned short * p = (const unsigned short*)(const void*)&Data[0];
     for(int i = 0; i < NumberOfPoints; i+=2)
       {
       os << p[i] << "," << p[i+1] << std::endl;
@@ -291,7 +291,7 @@ static const char * const TypeOfDataDescription[][2] = {
 { "FLOW" , "flow data" },
 { "PHYSIO" , "physio data" },
 { "RESP" , "Respiration trace" },
-{ 0 , 0 }
+{ nullptr , nullptr }
 };
 const char *Curve::GetTypeOfDataDescription() const
 {
@@ -468,7 +468,7 @@ void Curve::GetAsPoints(float *array) const
     {
     // PS 3.3 - 2004
     // C.10.2.1.5 Curve data descriptor, coordinate start value, coordinate step value
-    uint16_t * p = (uint16_t*)&Internal->Data[0];
+    uint16_t * p = (uint16_t*)(void*)&Internal->Data[0];
     // X
     if( genidx == 0 )
       for(int i = 0; i < Internal->NumberOfPoints; i++ )
@@ -504,7 +504,7 @@ void Curve::GetAsPoints(float *array) const
     }
   else if( Internal->DataValueRepresentation == 1 )
     {
-    int16_t * p = (int16_t*)&Internal->Data[0];
+    int16_t * p = (int16_t*)(void*)&Internal->Data[0];
     for(int i = 0; i < Internal->NumberOfPoints; i++ )
       {
       array[3*i+0] = p[mult*i + 0];
@@ -517,7 +517,7 @@ void Curve::GetAsPoints(float *array) const
     }
   else if( Internal->DataValueRepresentation == 2 )
     {
-    float * p = (float*)&Internal->Data[0];
+    float * p = (float*)(void*)&Internal->Data[0];
     for(int i = 0; i < Internal->NumberOfPoints; i++ )
       {
       array[3*i+0] = p[mult*i + 0];
@@ -530,7 +530,7 @@ void Curve::GetAsPoints(float *array) const
     }
   else if( Internal->DataValueRepresentation == 3 )
     {
-    double * p = (double*)&Internal->Data[0];
+    double * p = (double*)(void*)&Internal->Data[0];
     for(int i = 0; i < Internal->NumberOfPoints; i++ )
       {
       array[3*i+0] = (float)p[mult*i + 0];
@@ -543,7 +543,7 @@ void Curve::GetAsPoints(float *array) const
     }
   else if( Internal->DataValueRepresentation == 4 )
     {
-    int32_t * p = (int32_t*)&Internal->Data[0];
+    int32_t * p = (int32_t*)(void*)&Internal->Data[0];
     for(int i = 0; i < Internal->NumberOfPoints; i++ )
       {
       array[3*i+0] = (float)p[mult*i + 0];
