@@ -40,7 +40,7 @@ DirectionCosines::DirectionCosines(const double dircos[6])
   Values[5] = dircos[5];
 }
 
-DirectionCosines::~DirectionCosines() {}
+DirectionCosines::~DirectionCosines() = default;
 
 void DirectionCosines::Print(std::ostream &os) const
 {
