@@ -36,7 +36,7 @@ class FileChangeTransferSyntaxInternals
 {
 public:
   FileChangeTransferSyntaxInternals():
-    IC(NULL),
+    IC(nullptr),
     InitializeCopy(false)
   {}
   ~FileChangeTransferSyntaxInternals()
@@ -364,6 +364,13 @@ bool FileChangeTransferSyntax::InitializeCopy()
       Internals->Dims = ImageHelper::GetDimensionsValue(file);
       Internals->PF = ImageHelper::GetPixelFormatValue(file);
       Internals->PI = ImageHelper::GetPhotometricInterpretationValue(file);
+      if( Internals->PI == PhotometricInterpretation::YBR_FULL_422 &&
+        ( ts == TransferSyntax::ImplicitVRLittleEndian
+       || ts == TransferSyntax::ExplicitVRLittleEndian ) )
+        {
+        gdcmDebugMacro( "Don't know how to handle YBR_FULL_422/raw" );
+        return false;
+        }
       Internals->PC = ImageHelper::GetPlanarConfigurationValue(file);
       if( Internals->PC )
         {
