@@ -309,7 +309,7 @@ public:
           {
           // if you trigger this assertion, this means we have been allocating
           // memory for an element when not needed.
-          assert( (de.GetByteValue() && de.GetByteValue()->GetPointer() == 0) || de.GetSequenceOfFragments() );
+          assert( (de.GetByteValue() && de.GetByteValue()->GetPointer() == nullptr) || de.GetSequenceOfFragments() );
           }
         actualde = de.GetVL() + 2 * de.GetVR().GetLength() + 4;
         thepos -= actualde;
@@ -319,7 +319,7 @@ public:
         // no attribute found, easy case !
         }
       }
-    assert( pFile == NULL );
+    assert( pFile == nullptr );
     pFile = fopen(outfilename, "r+b");
     assert( pFile );
     CurrentDataLenth = 0;
@@ -586,7 +586,7 @@ public:
       }
 
     const size_t pclen = dicomdata.size();
-    assert( pFile == NULL );
+    assert( pFile == nullptr );
     pFile = fopen(outfilename, "r+b");
     assert( pFile );
 
