@@ -443,7 +443,7 @@ bool ImageChangeTransferSyntax::Change()
       {
       Bitmap &outbitmap = *Output;
       Pixmap *outpixmap = dynamic_cast<Pixmap*>( &outbitmap );
-      assert( outpixmap != NULL );
+      assert( outpixmap != nullptr );
       if( !pixmap->GetIconImage().IsEmpty() )
         {
         // same goes for icon
