@@ -260,7 +260,7 @@ bool Overlay::GrabOverlayFromPixelData(DataSet const &ds)
   if( Internal->BitsAllocated == 16 )
     {
     //assert( Internal->BitPosition >= 12 );
-    if( ds.FindDataElement( Tag(0x7fe0,0x0010) ) )
+    if( !ds.FindDataElement( Tag(0x7fe0,0x0010) ) )
       {
       gdcmWarningMacro("Could not find Pixel Data. Cannot extract Overlay." );
       return false;
