@@ -18,6 +18,7 @@
 #include "gdcmIPPSorter.h"
 #include "gdcmImageReader.h"
 #include "gdcmImageHelper.h"
+#include "gdcmAttribute.h"
 #include "gdcmTrace.h"
 
 namespace gdcm
@@ -28,7 +29,7 @@ SerieHelper::SerieHelper()
   Trace::WarningOff();
   UseSeriesDetails = false;
   Clear();
-  UserLessThanFunction = 0;
+  UserLessThanFunction = nullptr;
   DirectOrder = true;
   //LoadMode = 0;
 }
@@ -234,7 +235,7 @@ FileList *SerieHelper::GetFirstSingleSerieUIDFileSet()
   ItFileSetHt = SingleSerieUIDFileSetHT.begin();
   if ( ItFileSetHt != SingleSerieUIDFileSetHT.end() )
     return ItFileSetHt->second;
-  return NULL;
+  return nullptr;
 }
 
 FileList *SerieHelper::GetNextSingleSerieUIDFileSet()
@@ -244,7 +245,7 @@ FileList *SerieHelper::GetNextSingleSerieUIDFileSet()
   ++ItFileSetHt;
   if ( ItFileSetHt != SingleSerieUIDFileSetHT.end() )
     return ItFileSetHt->second;
-  return NULL;
+  return nullptr;
 }
 
 bool SerieHelper::UserOrdering(FileList *fileList)
@@ -262,6 +263,17 @@ bool MyFileNameSortPredicate(const SmartPointer<FileWithName>& d1, const SmartPo
 {
   return d1->filename < d2->filename;
 }
+bool MyInstanceSortPredicate(const SmartPointer<FileWithName>& d1, const SmartPointer<FileWithName>& d2)
+{
+  Attribute<0x0020,0x0013> instancenumber1;
+  Attribute<0x0020,0x0013> instancenumber2;
+  const DataSet& ds1 = d1->GetDataSet();
+  instancenumber1.SetFromDataSet( ds1 );
+  const DataSet& ds2 = d2->GetDataSet();
+  instancenumber2.SetFromDataSet( ds2 );
+
+  return instancenumber1.GetValue() < instancenumber2.GetValue();
+}
 }
 
 bool SerieHelper::FileNameOrdering( FileList *fileList )
@@ -271,6 +283,28 @@ bool SerieHelper::FileNameOrdering( FileList *fileList )
   return true;
 }
 
+bool SerieHelper::ImageNumberOrdering( FileList *fileList )
+{
+  Attribute<0x0020,0x0013> instancenumber;
+  std::set<int> instancenumbers;
+  for ( FileList::const_iterator
+    it = fileList->begin();
+    it != fileList->end(); ++it )
+    {
+    instancenumber.SetValue( -1 );
+    const DataSet& ds = (*it)->GetDataSet();
+    instancenumber.SetFromDataSet( ds );
+    int in = instancenumber.GetValue();
+    instancenumbers.insert( in );
+    }
+  if( instancenumbers.size() == fileList->size() )
+    {
+    std::sort(fileList->begin(), fileList->end(), details::MyInstanceSortPredicate);
+    return true;
+    }
+  return false;
+}
+
 bool SerieHelper::ImagePositionPatientOrdering( FileList *fileList )
 {
   //iop is calculated based on the file file
@@ -405,11 +439,10 @@ void SerieHelper::OrderFileList(FileList *fileSet)
     {
     return ;
     }
-  /*
   else if ( ImageNumberOrdering(fileSet ) )
   {
   return ;
-  }*/
+  }
   else
   {
   FileNameOrdering(fileSet );
