@@ -23,7 +23,7 @@ namespace gdcm
 
 /**
  * \brief StringFilter
- * StringFilter is the class that make gdcm2.x looks more like gdcm1 and transform the binary blob
+ * \details StringFilter is the class that make gdcm2.x looks more like gdcm1 and transform the binary blob
  * contained in a DataElement into a string, typically this is a nice feature to have for wrapped language
  */
 class GDCM_EXPORT StringFilter
@@ -46,6 +46,8 @@ public:
   /// Directly from a Tag:
   std::string ToString(const Tag& t) const;
 
+  std::string ToString(const PrivateTag& t) const;
+
   /// Convert to string the ByteValue contained in a DataElement
   /// the returned elements are:
   /// pair.first : the name as found in the dictionary of DataElement
@@ -54,8 +56,6 @@ public:
   /// Directly from a Tag:
   std::pair<std::string, std::string> ToStringPair(const Tag& t) const;
 
-  GDCM_LEGACY(std::string FromString(const Tag&t, const char * value, VL const & vl))
-
   /// Convert to string the char array defined by the pair (value,len)
   std::string FromString(const Tag&t, const char * value, size_t len);
 
