@@ -125,7 +125,7 @@ bool FindStudyRootQuery::ValidateQuery(bool inStrict) const
   if (inStrict)
     {
     QueryBase* qb = BaseRootQuery::Construct( eStudyRootType, (EQueryLevel)ilevel );
-    if (qb == NULL)
+    if (qb == nullptr)
       {
       gdcmWarningMacro( "Invalid Query" );
       return false;
@@ -141,7 +141,7 @@ bool FindStudyRootQuery::ValidateQuery(bool inStrict) const
     }
   else //include all previous levels (ie, series gets study, image gets series and study)
     {
-    QueryBase* qb = NULL;
+    QueryBase* qb = nullptr;
 
     if (strcmp(theVal.c_str(), "STUDY ") == 0)
       {
