@@ -243,6 +243,10 @@ static const StreamOffset gdcmStreamOffsetDataFiles[] = {
 { "FUJI-ffff-MONO1-J2K.dcm",2052 },
 { "JPEGLosslessSeNonZero.dcm",760 },
 { "US-YBR_FULL_422-EVRLE.dcm",1554 },
+{ "Osirix10vs8BitsStored.dcm",73978 },
+{ "Bug_Siemens_PrivateIconNoItem.dcm",12978 },
+{ "HardcopyColor_YBR_RCT_J2K_PC1.dcm",2626 },
+{ "PET-GE-dicomwrite-PixelDataSQUNv2.dcm",7718 },
 
 /* Stopping condition */
 { nullptr ,0 },
